==> nextcloud-14.0.13.zip: nextcloud/apps/federatedfilesharing/l10n/ja.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "連携共有",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} からのリモート共有 {name} を追加してもよろしいですか？",
    "Remote share" : "リモート共有",
    "Remote share password" : "リモート共有のパスワード",
    "Cancel" : "キャンセル",
    "Add remote share" : "リモート共有を追加",
    "Copy" : "コピー",
    "Copied!" : "コピーしました！",
    "Not supported!" : "サポートされていません！",
    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
    "Invalid Federated Cloud ID" : "無効なクラウド共有ID",
    "Server to server sharing is not enabled on this server" : "このサーバーでは、サーバー間の共有が有効ではありません",
    "Couldn't establish a federated share." : "クラウド共有を接続できませんでした。",
    "Couldn't establish a federated share, maybe the password was wrong." : "クラウド共有を接続できませんでした。パスワードが間違っていませんか。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "クラウド共有リクエストが送信されました。招待が受信できます。通知を確認してください。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "フェデレーション共有を確立できませんでした。連合するサーバーが古すぎます（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "このサーバーからフェデレーショングループ共有を送信することはできません。",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "このアイテムはすでに %2$s と共有されているため、%1$s の共有に失敗しました",
    "Not allowed to create a federated share with the same user" : "同じユーザーでクラウド共有は作成できません。",
    "File is already shared with %s" : "ファイルはすでに %s と共有されています。",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s の共有に失敗しました。%2$s が見つかりませんでした。おそらくサーバーに接続できないか、自己証明書を使用しています。",
    "Could not find share" : "共有が見つかりませんでした",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s からリモート共有として \"%3$s\" を受け取りました。(%2$s の代理として)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} からリモート共有として {share} を受け取りました。({behalf} の代理として)",
    "You received \"%3$s\" as a remote share from %1$s" : "%1$s からリモート共有として \"%3$s\" を受け取りました。",
    "You received {share} as a remote share from {user}" : "{user} から {file} のリモート共有が届いています",
    "Accept" : "承諾",
    "Decline" : "拒否《はてなキーワード》",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "#Nextcloud の「クラウド共有ID」で私と共有できます。こちらを見てください。%s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud の「クラウド共有ID」で私と共有できます。",
    "Sharing" : "共有中",
    "Federated file sharing" : "連携共有",
    "Provide federated file sharing across servers" : "サーバー間でフェデレーションファイル共有を提供する",
    "Federated Cloud Sharing" : "統合されたクラウド共有",
    "Open documentation" : "ドキュメントを開く",
    "Adjust how people can share between servers." : "サーバー間でどうやって共有するかを調整します。",
    "Allow users on this server to send shares to other servers" : "ユーザーがこのサーバーから他のサーバーに共有することを許可する",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Allow users on this server to send shares to groups on other servers" : "ユーザーがこのサーバーから他のサーバー上のグループに共有することを許可する",
    "Allow users on this server to receive group shares from other servers" : "ユーザーが他のサーバーからこのサーバーにグループ共有することを許可する",
    "Search global and public address book for users" : "グローバルまたはユーザーの公開アドレス帳を検索する",
    "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する",
    "Federated Cloud" : "クラウド共有",
    "Your Federated Cloud ID:" : "あなたのクラウド共有ID：",
    "Share it so your friends can share files with you:" : "友達があなたとファイルを共有できるよう、シェアしましょう:",
    "Add to your website" : "ウェブサイトに追加",
    "Share with me via Nextcloud" : "Nextcloud 経由で共有",
    "HTML Code:" : "HTMLコード:",
    "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないか、自己証明書を使っています。"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.3.zip: nextcloud/apps/federatedfilesharing/l10n/ja.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "連携共有",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} からのリモート共有 {name} を追加してもよろしいですか？",
    "Remote share" : "リモート共有",
    "Remote share password" : "リモート共有のパスワード",
    "Cancel" : "キャンセル",
    "Add remote share" : "リモート共有を追加",
    "Copy" : "コピー",
    "Copied!" : "コピーしました！",
    "Not supported!" : "サポートされていません！",
    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
    "Invalid Federated Cloud ID" : "無効なクラウド共有ID",
    "Server to server sharing is not enabled on this server" : "このサーバーでは、サーバー間の共有が有効ではありません",
    "Couldn't establish a federated share." : "クラウド共有を接続できませんでした。",
    "Couldn't establish a federated share, maybe the password was wrong." : "クラウド共有を接続できませんでした。パスワードが間違っていませんか。",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "クラウド共有リクエストが送信されました。招待が受信できます。通知を確認してください。",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "フェデレーション共有を確立できませんでした。連合するサーバーが古すぎます（Nextcloud <= 9）。",
    "It is not allowed to send federated group shares from this server." : "このサーバーからフェデレーショングループ共有を送信することはできません。",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "このアイテムは既に %2$s と共有されているため、%1$s の共有に失敗しました",
    "Not allowed to create a federated share with the same user" : "同じユーザーでクラウド共有は作成できません。",
    "File is already shared with %s" : "ファイルはすでに %s と共有されています。",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s の共有に失敗しました。%2$s が見つかりませんでした。おそらくサーバーに接続できないか、自己証明書を使用しています。",
    "Could not find share" : "共有が見つかりませんでした",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s からリモート共有として \"%3$s\" を受け取りました。(%2$s の代理として)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} からリモート共有として {share} を受け取りました。({behalf} の代理として)",
    "You received \"%3$s\" as a remote share from %1$s" : "%1$s からリモート共有として \"%3$s\" を受け取りました。",
    "You received {share} as a remote share from {user}" : "{user} から {file} のリモート共有が届いています",
    "Accept" : "承諾",
    "Decline" : "拒否《はてなキーワード》",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "#Nextcloud の「クラウド共有ID」で私と共有できます。こちらを見てください。%s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud の「クラウド共有ID」で私と共有できます。",
    "Sharing" : "共有中",
    "Federated file sharing" : "連携共有",
    "Provide federated file sharing across servers" : "サーバー間でフェデレーションファイル共有を提供する",
    "Federated Cloud Sharing" : "統合されたクラウド共有",
    "Open documentation" : "ドキュメントを開く",
    "Adjust how people can share between servers." : "サーバー間でどうやって共有するかを調整します。",
    "Allow users on this server to send shares to other servers" : "ユーザーがこのサーバーから他のサーバーに共有することを許可する",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Allow users on this server to send shares to groups on other servers" : "ユーザーがこのサーバーから他のサーバー上のグループに共有することを許可する",
    "Allow users on this server to receive group shares from other servers" : "ユーザーが他のサーバーからこのサーバーにグループ共有することを許可する",
    "Search global and public address book for users" : "グローバルまたはユーザーの公開アドレス帳を検索する",
    "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する",
    "Federated Cloud" : "クラウド共有",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud 、 ownCloud 、 Pydio を使う人とは誰とでも共有できます。クラウド共有IDを共有ダイアログに入力するだけです。例：person@cloud.example.com",
    "Your Federated Cloud ID:" : "あなたのクラウド共有ID：",
    "Share it so your friends can share files with you:" : "友達があなたとファイルを共有できるよう、シェアしましょう:",
    "Add to your website" : "ウェブサイトに追加",
    "Share with me via Nextcloud" : "Nextcloud 経由で共有",
    "HTML Code:" : "HTMLコード:",
    "The mountpoint name contains invalid characters." : "マウントポイント名 に不正な文字列が含まれています。",
    "Not allowed to create a federated share with the owner." : "その所有者でクラウド共有を作成することはできません",
    "Invalid or untrusted SSL certificate" : "無効または信頼できないSSL証明書",
    "Could not authenticate to remote share, password might be wrong" : "リモート共有が認証できませんでした，パスワードが間違っているかもしれません",
    "Storage not valid" : "ストレージが無効です",
    "Federated share added" : "クラウド共有が追加されました",
    "Couldn't add remote share" : "リモート共有を追加できませんでした",
    "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないか、自己証明書を使っています。"
},
"nplurals=1; plural=0;");
